
import { ClientExtensions } from '../constants';
import  './editor-input-factory-registry';
import { IEditorInputFactoryRegistry, IEditorInputFactory } from '@workbench-stack/core';
import 'jest';
import { Registry } from '@vscode/monaco-editor/esm/vs/platform/registry/common/platform';
import { URI } from '@vscode/monaco-editor/esm/vs/base/common/uri';


class TestEditorInputFactory implements IEditorInputFactory {

    constructor() {}

    public get input() {

        return {
            size: 0,
            mime: 0,
        };
    }
    public createInput(resource: URI, encoding: string | undefined, mode: string | undefined) {
        const result = Object.assign(this.input, {
            __typename: 'FileEditorInput',
            resource: resource.toString(),
            encoding,
            mode,

        });

        return result;
    }

}
class TestGitInputFactory implements IEditorInputFactory {

    constructor() {}
    public get input() {

        return {

        };
    }
    public createInput(resource: URI, encoding: string | undefined, mode: string | undefined) {
        const result = Object.assign(this.input, {
            __typename: 'GitEditorInput',
            encoding,
            mode,
            // editorId: 1,
            resource: resource.toString(),
        });

        return result;
    }
}
describe('Workbench editor groups', () => {

    // Register multiple factories based on the URI scheme
    Registry.as<IEditorInputFactoryRegistry>(ClientExtensions.EditorInputFactories).registerEditorInputFactory('file', new TestEditorInputFactory);
    Registry.as<IEditorInputFactoryRegistry>(ClientExtensions.EditorInputFactories).registerEditorInputFactory('git', new TestGitInputFactory);
    it('Editor Input', () => {

        const factory = Registry.as<IEditorInputFactoryRegistry>(ClientExtensions.EditorInputFactories);
        // sending input with resource scheme `file` so the `TestEditorInputFactory` is selected.
        const input = factory.getEditorInput(URI.parse('file:/file'), 'test', 'utf8', 'mode' );
        console.log(input);

        // registerEditorInputFactory();
    });

    it('Git Editor Input', () => {
        const factory = Registry.as<IEditorInputFactoryRegistry>(ClientExtensions.EditorInputFactories);
        // sending input with resource scheme `git` so the `TestGitInputFactory` is selected.
        const input = factory.getEditorInput(URI.parse('git:/file'), 'test', 'utf8', 'mode' );
        console.log(input);
    });
});

